// Reflecting cones
// Scene by: Craig Lindley
// Last Update: 09/21/06

#include "colors.inc"

global_settings { 
  max_trace_level 50 
  max_intersections 128
}

// Camera specification
camera {
  location <0,0,-10>
  right x*image_width/image_height
  look_at <0,0,0>
}

// Define the light sources
light_source {
   <-10,-10,0>
   color Blue
}
light_source {
   <10,10,0>
   color Gold
}


// Cone parameters
#declare cone_radius = 5;
#declare cone_height = 10;


// Highly reflective finish
declare cone_finish =

finish {
  ambient 0
  diffuse 1
  brilliance 30
  specular 1
  reflection 0.7
  phong 10 
  phong_size 200
  metallic
}

#declare surround = 
  sphere { 
    <0,0,0>, 20
    hollow    
    texture {
      pigment {
        color <1,1,1>
      }
      finish {
        ambient 0
        diffuse 0.5
        brilliance 5
        reflection 0.75
      }
    }
  }

#declare pointed_cone =
  cone {
    cone_height*y, cone_radius,
    0*y, 0
    texture {
      pigment {
        color <1,1,1>
      }
      finish {
        cone_finish
      }
    }
  }
    

// Define the four cones
#declare cone1 =
  cone { 
    pointed_cone
    rotate x*90 
    translate z*1
   }

#declare cone2 =
  cone { 
    pointed_cone
    translate y*1
   }

#declare cone3 =
  cone { 
    pointed_cone
    rotate 180*x
    translate y*-1 
   }

#declare cone4 =
  cone { 
    pointed_cone
    rotate z*90 
    translate x*-1
   }

#declare cone5 =
  cone { 
    pointed_cone
    rotate z*-90 
    translate x*1
   }

// Define the complete scene

sphere { surround }
cone { cone1 }
cone { cone2 }
cone { cone3 }
cone { cone4 }
cone { cone5 }
