// Reflecting cones and cylinders
// Scene by: Craig Lindley
// Last Update: 09/25/06

#include "colors.inc"

// Camera specification
camera {
  location <0,0,-26>
  right x*image_width/image_height
  look_at <0,0,0> 
  angle 20
}

// Define the light sources
light_source {
   <-130,130,-17>
   color Gold
}
light_source {
   <130,-130,-17>
   color Blue
}

light_source {
   <-24,13,-20>
   color Blue
}
light_source {
   <0,0,-70>
   color Gold
}


// Highly reflective finish
declare material_finish =

finish {
  ambient 0
  diffuse 1
  brilliance 80
  specular 1
  reflection 0.8
  phong 10 
  phong_size 100
  metallic
}



sphere {
  <0,0,0> 80
  hollow
    texture {
      pigment {
        color <0,0,0>
      }
finish {
  ambient 0
  diffuse 1
  brilliance 20
  specular 1
  reflection .4
  phong 10 
  phong_size 100
  metallic
}
    }
  }  

// Cone parameters
#declare cone_radius = 7;
#declare cone_height = 35;

#declare a_cone =
  cone {
    cone_height*y, cone_radius,
    0*y, 0
    texture {
      pigment {
        color Gold
      }
      finish {
        material_finish
      }
    }
  }
    
#declare cyl_radius = 4;
#declare cyl_height = 200;

#declare a_cyl =
  cylinder {
    <0,0,0>
    <0,cyl_height,0> 
    cyl_radius
    texture {
      pigment {
        color Gold
      }
      finish {
        material_finish
      }
    }
  }    
  
#declare rear_sphere =
  sphere { 
    <0,0,0> 7 
    hollow
    texture {
      pigment {
        color <1,1,1>
      }
      finish {
        material_finish
      }
    }
  }
  
#declare cyl1 =
  cylinder { 
    a_cyl
    translate y*1
   }

#declare cyl2 =
  cylinder { 
    a_cyl
    rotate x*-180
    translate y*-1
   }

#declare cyl3 =
  cylinder { 
    a_cyl
    rotate z*90 
    translate x*-1
   }

#declare cyl4 =
  cylinder { 
    a_cyl
    rotate z*-90 
    translate x*1
   }

#declare cyls = 
  composite {
    cone { cyl1 }
    cone { cyl2 }
    cone { cyl3 }
    cone { cyl4 }
  }
      

// Define the four cones
#declare cone1 =
  cone { 
    a_cone
    translate y*1
   }

#declare cone2 =
  cone { 
    a_cone
    rotate x*-180
    translate y*-1
   }

#declare cone3 =
  cone { 
    a_cone
    rotate z*90 
    translate x*-1
   }

#declare cone4 =
  cone { 
    a_cone
    rotate z*-90 
    translate x*1
   }

#declare cones = 
  composite {
    cone { cone1 }
    cone { cone2 }
    cone { cone3 }
    cone { cone4 }
  }
      
// Define the complete scene

sphere { rear_sphere translate z*10 }
composite { cones }
composite { cyls rotate z*45 translate z*8 }
