// Port of a desert scene from DKBTrace
// Scene by: Craig Lindley
// Last Update: 08/13/2006

global_settings { assumed_gamma 2.2 }

#include "colors.inc"
#include "stones.inc"  
#include "textures.inc"  
#include "shapes.inc"
                               

// Camera - perspective (default) camera
camera {
   location <0,15,-42>
   look_at <0,8,0>
   right     x*image_width/image_height
//   rotate <0 15 0>
}

// Light source
light_source {
  <0,50,-100>
  color Orange
}

// Define star texture
#declare nite_sky = object {
  plane { <0,0,1> 5000 }
  texture {
    pigment {
      granite
      color_map {
        [0.00 0.76 color Black  color Black]
        [0.80 0.82 color Gray20 color Gray40]
        [0.82 0.84 color Gray40 color Gray60]
        [0.84 0.86 color Gray60 color Gray80]
        [0.86 0.88 color Gray80 color Gray95]
        [0.88 0.91 color Gray95 color White]
        [0.91 1.00 color Black  color Black]
      }
      scale 200
    }
    finish { ambient 1 diffuse 0 }
  }
}
    
// Define the desert floor
#declare desert_floor = object {
   plane { <0,1,0>, 0 }
   texture {
     pigment { color Gold }
     normal {           
       ripples 2
       frequency 25
       scale <105,100,20>
     } 
   }
   finish {
     ambient 0.1
     diffuse 0.9
   }
}  


// Start definition of Seguaro cactus  

#declare cactus_texture = texture {
  pigment {
    bozo
    turbulence 0.5
    color_map {
      [0.0 0.8  color LimeGreen color LimeGreen ]
      [0.8 1.00 color LimeGreen color Black ]
    }
  }
  scale < 3 2 1 >
}

#declare large_cap = object {
  intersection {
    sphere { <0,0,0>  1 }
    plane { <0,-1,0>, 0 }
  }
  texture { cactus_texture }
}

#declare small_cap = object {
  intersection {
    sphere { <0,0,0> 0.75 }
    plane { <0,-1,0>, 0.0 }
  }
  texture { cactus_texture }
}

#declare trunk = object {
  cylinder {
    <0,27,0>,
    <0,0,0>,
    1
    open
  }
  texture { cactus_texture }
}

#declare arm = object {
  cylinder {
    <3.75,0,0>,
    <0,0,0>,
    0.75
    open
  }
  texture { cactus_texture }
}


#declare joint = object {
  sphere { <0,0,0> 0.75 }
  texture { cactus_texture }
}

#declare left_upright = object {
  cylinder {
    <0,11,0>,
    <0,0,0>,
    0.75
    open
  }
  texture { cactus_texture }
}

#declare right_upright = object {
  cylinder {
    <0,13,0>,
    <0,0,0>,
    0.75
    open
  }
  texture { cactus_texture }
}

#declare cactus = composite {
    object { trunk                                    }
    object { large_cap     translate <0.0,27.0,0.0>   }
    object { arm           translate <-3.75,9.0,0.0>  }
    object { arm           translate <0.0,12.0,0.0>   }
    object { joint         translate <-3.75,9.0,0.0>  }
    object { joint         translate <3.75,12.0,0.0>  }
    object { left_upright  translate <-3.75,9.0,0.0>  }
    object { right_upright translate <3.75,12.0,0.0>  }
    object { small_cap     translate <-3.75,20.0,0.0> }
    object { small_cap     translate <3.75,25.0,0.0>  }
}

// Define prickly pear cactus
#declare leaf = object {
  intersection {
    sphere { 
      <0,0,0> 1
      scale <0.57,1.17,0.57>
      translate <0,1.17,0>
    }
    plane { <0,0,-1>, 0.05 }
    plane { <0,0,1>, 0.05 }
  }
  pigment { color MediumForestGreen }
  texture { normal { wrinkles 0.3 } }
}

#declare flower = object {
  sphere { <0,2.33,0> 0.19 }
  pigment {color OrangeRed }
}

#declare whole_leaf = composite {
  object { leaf }
  object { flower }
}

#declare prickly_pear = composite {
  object { leaf }
  composite { whole_leaf rotate <0,0,45> }
  composite { whole_leaf rotate <0,0,-45> }
  bounded_by {
    sphere { <0,1.5,0> 1.75 }
  }
}

// Define the well
#declare well = object {
  intersection {
    sphere { <0,0,0> 5.32 }
    sphere { <0,0,0 > 4.56 inverse }
    plane { <0,1,0>, 3.42 }
    plane { <0,-1,0>, 0.0 }
  }
  bounded_by {
    sphere { <0.0,0.0,0.0> 5.33 }
  }
  texture { Dark_Wood scale 20 }
  finish {
    diffuse 0.7
    ambient 0.3
  }
  translate <15,0,-10>
}

// Define the complete scene
object { nite_sky } 
object { desert_floor }
object { well }

composite { prickly_pear 
  rotate <0,10,0>
  translate <-6,0,-20>
}
composite { prickly_pear
  rotate <0,-60,0>
  translate <21,0,-7>
}
composite { prickly_pear 
  translate <-2,0,-10>
}  
      
      
composite { cactus }
composite { cactus translate <15,0,-31> }







composite { cactus rotate <0,45,0> translate <35,0,-40> }
composite { cactus translate <-30,0,20> }
composite { cactus translate < -28 0 30.24> }
composite { cactus rotate <0 180 0> translate <34 0 34.56 > }
composite { cactus rotate <0 40 0 > translate <-30.98 0 34.56 > }
composite { cactus rotate <0 -30 0> translate <29 0 70 > }
composite { cactus rotate <0  60 0> translate <-30.98 0 80 > }
composite { cactus rotate <0 180 0> translate <-100 0 60 > }
composite { cactus rotate <0  60 0> translate <-85 0 100 > }
composite { cactus rotate <0 -80 0> translate <-60 0 200 > }
composite { cactus rotate <0  75 0> translate <-128 0 200 > }





 