package com.craigl.artrays;

import java.io.*;

public class ExecPOV {
	
	private static final int DEFAULT_WIDTH = 640;
	private static final int DEFAULT_HEIGHT = 480;
	private static final boolean DEFAULT_ANTIALIASING = false;
	
	private static final int MAX_CMDLINE_ARGS = 8;
	
    class StreamHandler extends Thread
    {
        InputStream is;
        OutputStream os;
        
        StreamHandler(InputStream is, OutputStream os)
        {
            this.is = is;
            this.os = os;
        }
        
        public void run()
        {
            try
            {
                int c;
                
                while ((c = is.read()) != -1)
                {
                    os.write(c);
                    os.flush();
                }
            }
            catch (IOException e)
            {
            }
        }
    
    }

    // Class constructor
	public ExecPOV(PropertyManager pm) {
		
		// Get path/name of POVRay executable
		povexe = pm.getPOVExe();
		
		// Set up the defaults
		useAntiAliasing = DEFAULT_ANTIALIASING;
		width = DEFAULT_WIDTH;
		height = DEFAULT_HEIGHT;
	}
	
	public void setAntiAliasing(boolean b) {		
		useAntiAliasing = b;
	}
	
	public void setWidth(int width) {
		this.width = width;
	}
 
	public void setHeight(int height) {
		this.height = height;
	}
	
	// Set the input file to render
	public void setInputFile(String inFile) {
		this.inFile = inFile;
	}
	
	// Set the output file
	public void setOutputFile(String outFile) {
		this.outFile = outFile;
	}
	
	// Attempt the exec
	public boolean execPOV() {
		
		// Nothing to do if in or out files not specified
		if ((inFile == null) || (outFile == null)) {
			return false;
		}		
		// Create array of command line arguments
		cmdlineArgs = new String[MAX_CMDLINE_ARGS];
		
		// Build the command line
		cmdlineArgs[0] = povexe;
		cmdlineArgs[1] = "info.ini";
		cmdlineArgs[2] = "+W" + String.valueOf(width);
		cmdlineArgs[3] = "+H" + String.valueOf(height);
		cmdlineArgs[4] = (useAntiAliasing) ? "+A" : "-A";
		cmdlineArgs[5] = "+FN"; // Output PNG file
		cmdlineArgs[6] = "+I" + inFile;
		cmdlineArgs[7] = "+O" + outFile;

		// Get instance of runtime environment
		Runtime rt = Runtime.getRuntime();
		
		try {
			// Attempt the exec
			Process p = rt.exec(cmdlineArgs);

	        // Any error from the process?
	        StreamHandler errorStream = new  StreamHandler(p.getErrorStream(), System.err);
	        
	        // Any output from the process?
	        StreamHandler outputStream = new StreamHandler(p.getInputStream(), System.out);
	            
	        // Any input to the process?
	        StreamHandler inputStream = new StreamHandler(System.in, p.getOutputStream());
	        
	        // Start the stream threads
	        errorStream.start();
	        outputStream.start();
	        inputStream.start();
			
			// Wait for process to complete
			p.waitFor();

			return true;

		} catch (Exception e) {
			System.out.println(e.getMessage());
			return false;
		}
	}
/*			
	// Values used for testing
	private static final String INFILE = "\\artrays\\povfiles\\image3.pov";
	private static final String OUTDIR = "\\artrays\\povimages\\";

	// Test entry point
	public static void main(String[] args) {
		
		// Create new instance of class
		ExecPOV e = new ExecPOV();

		// Parameterize it
		e.setInputFile(INFILE);
		e.setOutputDirectory(OUTDIR);
		e.setWidth(640);
		e.setHeight(480);
		e.setAntiAliasing(true);
		
		// Do the rendering
		boolean result = e.execPOV();
		
		System.out.println("Exec result: " + result);
	}
*/	
	// Instance data
	private String povexe;
	private boolean useAntiAliasing;
	private int width;
	private int height;
	private String inFile;
	private String outFile;
	private String [] cmdlineArgs;
}
