package com.craigl.artrays;

import java.awt.*;
import java.awt.image.BufferedImage;
import java.io.*;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import javax.imageio.ImageIO;
import javax.swing.JFrame;
 
public class FSDisplay extends JFrame {
 
	// this line is needed to avoid serialization warnings 
	private static final long serialVersionUID = 1L; 
	
	// Class constructor 
	public FSDisplay() {
		
		// Set up exit handling
 
		// Exit program on window close
		addWindowListener(new WindowAdapter() {
            public void windowClosing(WindowEvent e) {
                System.exit(0);
            }
        });
 
		// Exit program on mouse click
		addMouseListener(new MouseListener() {
			public void mouseClicked(MouseEvent e) { System.exit(0); }
			public void mousePressed(MouseEvent e) {}
			public void mouseReleased(MouseEvent e) {}
			public void mouseEntered(MouseEvent e) {}
			public void mouseExited(MouseEvent e) {}
		}
		);
		
		setBackground(Color.BLACK);
		
		// Remove window frame 
		setUndecorated(true);
		
		// Turn the mouse cursor off by installing bogus image for cursor
		Toolkit tk = Toolkit.getDefaultToolkit();
		
		// Create bogus image
		Image ci = tk.createImage("");
		
		setCursor(tk.createCustomCursor(ci, new Point(), null));
 
		// Make window visible
		setVisible(true);
 		 
		// Switch to fullscreen mode
		GraphicsEnvironment.getLocalGraphicsEnvironment().
		getDefaultScreenDevice().setFullScreenWindow(this);
 
		// Get display resolution
		frameWidth = getWidth();
		frameHeight = getHeight();
}
	
	// Set the image to be displayed should be PNG image
	public void setDisplayImage(final String pathToImage) {
		
		// Load new image fully into memory
		screenImage = null;
		
	    try {
	        screenImage = ImageIO.read(new File(pathToImage));
	      } catch (IOException ioe) {
	        System.err.println(ioe.getMessage());
	      }
		
		// Cause a repaint to display new image
		repaint();
	}
 
	// Paint the image into window
	public void paint(Graphics g) {

		// Fill rect with background color from Graphics context
		g.clearRect(0, 0, frameWidth, frameHeight);

		if (screenImage != null) {
			
			int imageWidth = screenImage.getWidth(this);
			int imageHeight = screenImage.getHeight(this);

			int xOffset = frameWidth / 2 - imageWidth / 2;
			int yOffset = frameHeight / 2 - imageHeight / 2;

			// If screenImage is not null paint it into center of window
			g.drawImage(screenImage, xOffset, yOffset, null);

			// Draw matte around image
			g.setColor(Color.WHITE);
			g.draw3DRect(xOffset, yOffset, imageWidth, imageHeight, true);
		}
	}

/*
 * private static final String IMAGE1 = "/artrays/povimages/image1.png"; private
 * static final String IMAGE2 = "/artrays/povimages/image2.png";
 *  // Test entry point public static void main(String[] args) {
 *  // Instantiate display class FSDisplay fsDisplay = new FSDisplay();
 * 
 * fsDisplay.setDisplayImage(IMAGE1);
 * 
 * try { Thread.sleep(5000); } catch (Exception e) { }
 * 
 * fsDisplay.setDisplayImage(IMAGE2);
 * 
 * try { Thread.sleep(5000); } catch (Exception e) { } }
 */	
	// Instance data
	private BufferedImage screenImage;
	private int frameWidth;
	private int frameHeight;
}
