package com.craigl.artrays;

import java.io.*;
import java.util.*;

public class PropertyManager {
	
	private static final String PROPERTY_FILE = "\\artrays\\artrays.properties";
	
	// Define the property keys
	private static final String KEY_SIGNON_IMAGE = "SIGNON_IMAGE";
	
	private static final String KEY_POV_EXE = "POV_EXE";

	private static final String KEY_IMAGE_MAP_DIR = "IMAGE_MAP_DIR";
	private static final String KEY_INPUT_DIR = "INPUT_DIR";
	private static final String KEY_OUTPUT_DIR = "OUTPUT_DIR";
	private static final String KEY_SCENE_DIR = "SCENE_DIR";

	private static final String KEY_SAVING = "SAVE_FILES";
	private static final String KEY_USE_SCENE = "USE_SCENE_EVERY";
	private static final String KEY_MODIFY_PALETTE = "MODIFY_PALETTE_EVERY";
	private static final String KEY_SOUND_ON = "SOUND_ON";
	private static final String KEY_DISPLAY = "DISPLAY";
	private static final String KEY_PIGMENT = "PIGMENT_RANDOMIZER";

	private static final String KEY_WIDTH = "WIDTH";
	private static final String KEY_HEIGHT = "HEIGHT";
	private static final String KEY_VARY_SIZE = "VARY_SIZE";
	private static final String KEY_ANTIALIASING = "ANTIALIASING";

	private static final String KEY_MAX_LIGHTS = "MAX_LIGHTS";
	private static final String KEY_MIN_BOXES = "MIN_BOXES";
	private static final String KEY_MAX_BOXES = "MAX_BOXES";
	private static final String KEY_MIN_CONES = "MIN_CONES";
	private static final String KEY_MAX_CONES = "MAX_CONES";
	private static final String KEY_MIN_CYLS = "MIN_CYLS";
	private static final String KEY_MAX_CYLS = "MAX_CYLS";
	private static final String KEY_MIN_SPHERES = "MIN_SPHERES";
	private static final String KEY_MAX_SPHERES = "MAX_SPHERES";
	
	// Class constructor
	public PropertyManager() {
		
		// Load the properties file
		props = new Properties();
		try {
			// Attempt to open property file
			InputStream is = new FileInputStream(PROPERTY_FILE);

			// Load the properties
			props.load(is);
			
		}	catch(Exception e) {
			System.err.println(e.getMessage());
			System.exit(-1);
		}
	}
	
	// Get the path/name of the signon image
	public String getSignOnImage() {
		return props.getProperty(KEY_SIGNON_IMAGE);
	}
	
	// Get the path/name of POVRay executable
	public String getPOVExe() {
		return props.getProperty(KEY_POV_EXE);
	}
	
	// Get the path to image map dir
	public String getImageMapDir() {
		return props.getProperty(KEY_IMAGE_MAP_DIR);
	}

	// Get the path to input dir
	public String getInputDir() {
		return props.getProperty(KEY_INPUT_DIR);
	}
	// Get the path to output dir
	public String getOutputDir() {
		return props.getProperty(KEY_OUTPUT_DIR);
	}

	// Get the path to scene dir
	public String getSceneDir() {
		return props.getProperty(KEY_SCENE_DIR);
	}
	
	public boolean getSaving() {
		String s = props.getProperty(KEY_SAVING);
		return Boolean.parseBoolean(s);
	}

	public int useSceneEveryN() {
		String s = props.getProperty(KEY_USE_SCENE);
		return Integer.parseInt(s);
	}

	public int modifyPaletteEveryN() {
		String s = props.getProperty(KEY_MODIFY_PALETTE);
		return Integer.parseInt(s);
	}

	public boolean getSoundOn() {
		String s = props.getProperty(KEY_SOUND_ON);
		return Boolean.parseBoolean(s);
	}

	public boolean getDisplaying() {
		String s = props.getProperty(KEY_DISPLAY);
		return Boolean.parseBoolean(s);
	}

	public int getPigmentRandomizer() {
		String s = props.getProperty(KEY_PIGMENT);
		return Integer.parseInt(s);
	}

	public int getWidth() {
		String s = props.getProperty(KEY_WIDTH);
		return Integer.parseInt(s);
	}

	public int getHeight() {
		String s = props.getProperty(KEY_HEIGHT);
		return Integer.parseInt(s);
	}

	public boolean getVarySize() {
		String s = props.getProperty(KEY_VARY_SIZE);
		return Boolean.parseBoolean(s);
	}

	public boolean getAntialiasing() {
		String s = props.getProperty(KEY_ANTIALIASING);
		return Boolean.parseBoolean(s);
	}

	public int getMaxLights() {
		String s = props.getProperty(KEY_MAX_LIGHTS);
		return Integer.parseInt(s);
	}

	public int getMinBoxes() {
		String s = props.getProperty(KEY_MIN_BOXES);
		return Integer.parseInt(s);
	}

	public int getMaxBoxes() {
		String s = props.getProperty(KEY_MAX_BOXES);
		return Integer.parseInt(s);
	}

	public int getMinCones() {
		String s = props.getProperty(KEY_MIN_CONES);
		return Integer.parseInt(s);
	}

	public int getMaxCones() {
		String s = props.getProperty(KEY_MAX_CONES);
		return Integer.parseInt(s);
	}

	public int getMinCyls() {
		String s = props.getProperty(KEY_MIN_CYLS);
		return Integer.parseInt(s);
	}

	public int getMaxCyls() {
		String s = props.getProperty(KEY_MAX_CYLS);
		return Integer.parseInt(s);
	}

	public int getMinSpheres() {
		String s = props.getProperty(KEY_MIN_SPHERES);
		return Integer.parseInt(s);
	}

	public int getMaxSpheres() {
		String s = props.getProperty(KEY_MAX_SPHERES);
		return Integer.parseInt(s);
	}

	// Instance data
	private Properties props;
}
